==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/body/impl/WhileStmtSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.body.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.ACT_SMTSet;
import io.ciera.tool.sql.ooaofooa.body.BlockSet;
import io.ciera.tool.sql.ooaofooa.body.WhileStmt;
import io.ciera.tool.sql.ooaofooa.body.WhileStmtSet;
import io.ciera.tool.sql.ooaofooa.body.impl.ACT_SMTSetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.BlockSetImpl;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.List;


public class WhileStmtSetImpl extends InstanceSet<WhileStmtSet,WhileStmt> implements WhileStmtSet {

    // attributes
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( WhileStmt whilestmt : this ) whilestmt.setStatement_ID( ref_Statement_ID );
    }
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( WhileStmt whilestmt : this ) whilestmt.setValue_ID( ref_Value_ID );
    }
    @Override
    public void setBlock_ID( UniqueId ref_Block_ID ) throws XtumlException {
        for ( WhileStmt whilestmt : this ) whilestmt.setBlock_ID( ref_Block_ID );
    }


    // selections
    @Override
    public ACT_SMTSet R603_is_a_ACT_SMT() throws XtumlException {
        ACT_SMTSet act_smtset = new ACT_SMTSetImpl();
        for ( WhileStmt whilestmt : this ) act_smtset.add( whilestmt.R603_is_a_ACT_SMT() );
        return act_smtset;
    }
    @Override
    public BlockSet R608_controls_Block() throws XtumlException {
        BlockSet blockset = new BlockSetImpl();
        for ( WhileStmt whilestmt : this ) blockset.add( whilestmt.R608_controls_Block() );
        return blockset;
    }
    @Override
    public ValueSet R626_continue_result_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( WhileStmt whilestmt : this ) valueset.add( whilestmt.R626_continue_result_Value() );
        return valueset;
    }


    @Override
    public WhileStmt nullElement() {
        return WhileStmtImpl.EMPTY_WHILESTMT;
    }

    @Override
    public WhileStmtSet emptySet() {
      return new WhileStmtSetImpl();
    }

    @Override
    public WhileStmtSet value() {
        return this;
    }

    @Override
    public List<WhileStmt> elements() {
        return Arrays.asList(toArray(new WhileStmt[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/body/impl/WhileStmtSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.body.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.ACT_SMTSet;
import io.ciera.tool.sql.ooaofooa.body.BlockSet;
import io.ciera.tool.sql.ooaofooa.body.WhileStmt;
import io.ciera.tool.sql.ooaofooa.body.WhileStmtSet;
import io.ciera.tool.sql.ooaofooa.body.impl.ACT_SMTSetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.BlockSetImpl;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class WhileStmtSetImpl extends InstanceSet<WhileStmtSet,WhileStmt> implements WhileStmtSet {

    public WhileStmtSetImpl() {
    }

    public WhileStmtSetImpl(Comparator<? super WhileStmt> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( WhileStmt whilestmt : this ) whilestmt.setStatement_ID( ref_Statement_ID );
    }
    @Override
    public void setBlock_ID( UniqueId ref_Block_ID ) throws XtumlException {
        for ( WhileStmt whilestmt : this ) whilestmt.setBlock_ID( ref_Block_ID );
    }
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( WhileStmt whilestmt : this ) whilestmt.setValue_ID( ref_Value_ID );
    }


    // selections
    @Override
    public ACT_SMTSet R603_is_a_ACT_SMT() throws XtumlException {
        ACT_SMTSet act_smtset = new ACT_SMTSetImpl();
        for ( WhileStmt whilestmt : this ) act_smtset.add( whilestmt.R603_is_a_ACT_SMT() );
        return act_smtset;
    }
    @Override
    public BlockSet R608_controls_Block() throws XtumlException {
        BlockSet blockset = new BlockSetImpl();
        for ( WhileStmt whilestmt : this ) blockset.add( whilestmt.R608_controls_Block() );
        return blockset;
    }
    @Override
    public ValueSet R626_continue_result_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( WhileStmt whilestmt : this ) valueset.add( whilestmt.R626_continue_result_Value() );
        return valueset;
    }


    @Override
    public WhileStmt nullElement() {
        return WhileStmtImpl.EMPTY_WHILESTMT;
    }

    @Override
    public WhileStmtSet emptySet() {
      return new WhileStmtSetImpl();
    }

    @Override
    public WhileStmtSet emptySet(Comparator<? super WhileStmt> comp) {
      return new WhileStmtSetImpl(comp);
    }

    @Override
    public WhileStmtSet value() {
        return this;
    }

    @Override
    public List<WhileStmt> elements() {
        return Arrays.asList(toArray(new WhileStmt[0]));
    }

}
